@@ -5,7 +5,7 @@ test_that("example works", {
   # skip_if_offline(host = "r-project.org")
 
 
-  vcr::use_cassette("gnrs_base", {
+  vcr::use_cassette("tnrs_base", {
     results <- TNRS:::TNRS_base(taxonomic_names = tnrs_testfile, url = url, skip_internet_check = TRUE)
   })
 
